<?php

/**
 * Header template
 *
 * @package 	Mino
 * @since 		1.0.0
 * @version		1.0.5
 */

?>

<!DOCTYPE html>
<html <?php language_attributes(); ?>>
<head>
	<meta charset="<?php bloginfo( 'charset' ); ?>">
	<meta http-equiv="X-UA-Compatible" content="IE=edge">
	<meta name="viewport" content="width=device-width, initial-scale=1">
	<?php do_action( 'mino-set-description' ); ?>
	<?php do_action( 'mino-set-og-card' ); ?>
	<link rel="profile" href="http://gmpg.org/xfn/11">
	<?php if ( is_singular() && pings_open( get_queried_object() ) ) : ?>
	<link rel="pingback" href="<?php bloginfo( 'pingback_url' ); ?>">
	<?php endif; ?>
	<?php wp_head(); ?>
</head>

<?php
	$add_class = null;
	if ( in_array( 'woocommerce/woocommerce.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ) ) ) {
		$add_class = mino_check_woocommerce_class();
	}
?>

<body <?php body_class( $add_class ); ?>>

	<div id="wrapper">

		<?php
			$mino_sln 	= esc_attr( get_theme_mod( 'mino_store_support_customizer_set' ) );
			$mino_es 	= esc_attr( get_theme_mod( 'mino_store_email_customizer_set' ) );
		?>

		<!-- Probably can choose one of them (header has banner or compact) -->

		<header class="masthead has-banner">
			<div class="header">

				<?php
					if ( in_array( 'woocommerce/woocommerce.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ) ) ) :
				?>

				<?php if ( ! empty( $mino_sln ) || ! empty( $mino_es ) ) : ?>
				<nav class="nav-bottom nav-top-commerce hidden-xs">
					<div class="container">
						<div class="clearfix">
							<div class="header-hotline-container col-md-6 col-sm-9">
								<div class="row">

									<?php if ( $mino_sln ) : ?>
									<div class="header-hotline">
										<div class="header-hotline-img-container">
											<i class="fa fa-phone color-theme"></i>
										</div>
										<label class="header-hotline-label">
											<?php _e( 'Support Line', 'mino' ); ?> : <?php echo esc_html( $mino_sln ); ?>
										</label>
									</div>
									<?php endif; ?>

									<?php if ( $mino_es ) : ?>
									<div class="header-hotline">
										<div class="header-hotline-img-container">
											<i class="fa fa-envelope-o color-theme"></i>
										</div>
										<label class="header-hotline-label">
											<?php _e( 'Email', 'mino' ); ?> : <?php echo esc_html( $mino_es ); ?>
										</label>
									</div>
									<?php endif; ?>

								</div>
							</div>
							<div class="header-menu-container col-md-6 col-sm-3">
								<?php do_action( 'mino_search_header' ); ?>
							</div>
						</div>
					</div>
				</nav>
				<?php endif; ?>

				<?php else : ?>

				<nav class="nav-top hidden-xs">
					<div class="container">
						<div class="clearfix">

							<?php
								if ( has_nav_menu( 'secondary' ) ) :

			                        $secondary = array(
			                            'theme_location'  	=> 'secondary',
			                            'menu'            	=> 'secondary',
			                            'menu_class'      	=> 'secondary-menu navbar pull-left',
			                            'container'			=> 'div',
			                            'container_id'		=> 'secondary-menu',
			                            'fallback_cb'     	=> 'wp_bootstrap_navwalker::fallback',
			                            'depth'           	=> 1,
			                            'walker'          	=> new wp_bootstrap_navwalker()
			                        );

			                        wp_nav_menu( $secondary );

			                    endif;

			                    if ( is_active_sidebar( 'header-widget' ) ) {
									dynamic_sidebar( 'header-widget' );
								}
							?>
						</div>

					</div>
				</nav>

				<?php endif; ?>

				<div class="container">
					<div class="main-content">
						<div class="clearfix">

							<?php do_action( 'mino_display_header' ); ?>

							<nav>
								<button type="button" class="menu-toggle">
									<span class="fa fa-bars"></span>
								</button>

								<?php
									$spec_class = '';
									if ( in_array( 'woocommerce/woocommerce.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ) ) ) :
										$spec_class = 'btn-search-mob-eco';
								?>
								<div class="hidden-lg hidden-md hidden-sm mino-cart-on-top">
									<div class="mino-mini-cart"></div>
								</div>
								<?php endif; ?>

								<button type="submit" class="btn-search pull-right <?php echo esc_attr( $spec_class ); ?>"><span class="fa fa-search"></span><span class="fa fa-times"></span></button>
							</nav>

						</div>
					</div>
				</div>

				<?php
					if ( in_array( 'woocommerce/woocommerce.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ) ) ) :
				?>
				<nav class="nav-bottom nav-added-sticky-here">
					<div class="container">
						<div class="clearfix">

							<div id="main-menu" class="main-menu-container pull-left col-md-7 col-sm-8 nopad nopad-mb nopad-sm">
							<?php
								if ( has_nav_menu( 'primary' ) ) :

			                        $primary = array(
			                            'theme_location'  	=> 'primary',
			                            'menu'            	=> 'primary',
			                            'menu_class'      	=> 'main-menu navbar',
			                            'fallback_cb'     	=> 'wp_bootstrap_navwalker::fallback',
			                            'depth'           	=> 3,
			                            'walker'          	=> new wp_bootstrap_navwalker()
			                        );

			                        wp_nav_menu( $primary );

			                    endif;
							?>
								<div class="header-hotline-mobile">
									<div class="header-menu-ext visible-xs account-access clearfix">

									<?php if ( is_user_logged_in() ) : ?>
									 	<div class="col-xs-6 text-center">
									  		<a href="<?php echo esc_url( get_permalink( get_option('woocommerce_myaccount_page_id') ) ); ?>" class="btn btn-success">
									  			<i class="fa fa-user"></i>
									  			<?php _e( 'My Account', 'mino' ); ?>
									  		</a>
									  	</div>
									  	<?php
											$logout_url = mino_woocommerce_logout();
										?>
									 	<div class="col-xs-6 text-center">
									 		<a href="<?php echo esc_url( $logout_url ); ?>" class="btn btn-success">
									 			<i class="fa fa-sign-out"></i>
									 			<?php _e( 'Logout', 'mino' ); ?>
									 		</a>
										</div>
									<?php else : ?>
										<div class="col-xs-8 col-xs-offset-2 text-center">
									  		<a href="<?php echo esc_url( get_permalink( get_option('woocommerce_myaccount_page_id') ) ); ?>" class="btn btn-success">
									  			<i class="fa fa-user"></i>
									  			<?php _e( 'Login/Register', 'mino' ); ?>
									  		</a>
									  	</div>
									<?php endif; ?>

									</div>

									<div class="header-hotline-container visible-xs">

										<?php if ( $mino_sln ) : ?>
										<div class="header-hotline">
											<div class="header-hotline-img-container">
												<i class="fa fa-phone color-theme"></i>
											</div>
											<label class="header-hotline-label">
												<?php echo esc_html( $mino_sln ); ?>
											</label>
										</div>
										<?php endif; ?>

										<?php if ( $mino_es ) : ?>
										<div class="header-hotline">
											<div class="header-hotline-img-container">
												<i class="fa fa-envelope-o color-theme"></i>
											</div>
											<label class="header-hotline-label">
												<?php echo esc_html( $mino_es ); ?>
											</label>
										</div>
										<?php endif; ?>

									</div>
									<div class="header-menu-ext visible-xs">
										<i class="fa fa-times hide-mini-cart"></i>
										<div class="mino-mini-cart"></div>
									</div>
								</div>
							</div>
							<div class="col-md-5 col-sm-4 nav-top-commerce nopad-mb nopad-sm">
								<div class="header-menu-container hidden-xs">
									<div class="pull-right">
										<div class="mino-mini-cart"></div>
									</div>
									<div id="secondary-ecommerce-menu" class="pull-right">
										<ul id="menu-woocommerce-menu" class="main-menu navbar">
											<li class="my-account-menu menu-item menu-item-has-children dropdown">
											<?php if ( is_user_logged_in() ) : ?>
											 	<a title="My Account" href="#" data-toggle="dropdown" class="dropdown" aria-haspopup="true">
													<?php _e( 'My Account', 'mino' ); ?> <span class="caret"></span>
												</a>
												<ul role="menu" class=" dropdown-menu sub-menu">
												<?php
													$logout_url = mino_woocommerce_logout();
												?>
													<li class="menu-item menu-item-type-custom menu-item-object-custom">
														<a title="Account" href="<?php echo esc_url( get_permalink( get_option('woocommerce_myaccount_page_id') ) ); ?>">
															<?php _e( 'Account', 'mino' ); ?>
														</a>
													</li>
													<li class="menu-item menu-item-type-custom menu-item-object-custom">
														<a title="Logout" href="<?php echo esc_url( $logout_url ); ?>">
															<?php _e( 'Logout', 'mino' ); ?>
														</a>
													</li>
												</ul>
											<?php else : ?>
												<a title="My Account" href="<?php echo esc_url( get_permalink( get_option('woocommerce_myaccount_page_id') ) ); ?>">
													<?php _e( 'My Account', 'mino' ); ?>
												</a>
											<?php endif; ?>
											</li>
										</ul>
									</div>
								</div>
							</div>
							<div class="hidden-lg hidden-md hidden-sm">
								<?php do_action( 'mino_search_header' ); ?>
							</div>
						</div>
					</div>
				</nav>

				<?php else : ?>

				<nav class="nav-bottom">
					<div class="container">
						<div class="clearfix">

							<div id="main-menu" class="main-menu-container pull-left">
							<?php
								if ( has_nav_menu( 'primary' ) ) :

			                        $primary = array(
			                            'theme_location'  	=> 'primary',
			                            'menu'            	=> 'primary',
			                            'menu_class'      	=> 'main-menu navbar',
			                            'fallback_cb'     	=> 'wp_bootstrap_navwalker::fallback',
			                            'depth'           	=> 3,
			                            'walker'          	=> new wp_bootstrap_navwalker()
			                        );

			                        wp_nav_menu( $primary );

			                    endif;
							?>
							</div>
							<?php do_action( 'mino_search_header' ); ?>
						</div>
					</div>
				</nav>

				<?php endif; ?>

			</div>
		</header>

		<div class="site-content">

			<?php do_action( 'mino_index_page_cover' ); ?>

			<div class="container main-container">
				<div class="row">