<?php

/**
 * Template Name: Blog Page
 *
 * Blog Page page template is used to display post list. For example,
 * we can display post list in Blog page when home page is used to 
 * display shop page or products only, not posts.
 * 
 * @package Mino
 * @since   1.0.5
 * @version 1.0.7
 */

get_header();

$bar        = mino_get_layout_bar();
$mainbar    = $bar['mainbar_class']; ?>

<div id="primary" class="<?php echo esc_attr( $mainbar ); ?> content-area">
    <div class="main-content" id="archive-page">

        <?php

            /* Set data */
            $posts_per_page = get_option( 'posts_per_page' );

            $paged  = 1;

            /**
             * Use get_query_var to get pagination number
             */
            
            $paged_one = get_query_var('paged');
            $paged_two = get_query_var('page');

            if ( ! empty( $paged_one ) ) {
                $paged = absint( $paged_one );
            } else if ( ! empty( $paged_two ) ) {
                $paged = absint( $paged_two );
            }

            $offset = $posts_per_page * ( $paged - 1 );

            $args = array(
                'posts_per_page'   => $posts_per_page,
                'offset'           => $offset,
                'orderby'          => 'date',
                'order'            => 'DESC',
                'post_type'        => 'post',
                'post_status'      => 'publish',
                'suppress_filters' => true
            );

            /* Ignore sticky */
            $args['post__not_in'] = get_option( 'sticky_posts' );

            $posts_array = new WP_Query( $args );

            if ( $posts_array->have_posts() ) :

                /* Check thumbnail show */
                $show_thumbnail = get_theme_mod( 'mino_index_thumbnail_customizer_set', 1 );

                /* Start the loop */
                while ( $posts_array->have_posts() ) : $posts_array->the_post();

        ?>

                <?php if ( $show_thumbnail ) : ?>

                <article id="post-<?php the_ID(); ?>" <?php post_class( 'post-thumb-list' ); ?>>
                    <div class="row">
                        <div class="img-thumb col-md-4">
                            <div class="thumbnail">
                                <a href="<?php the_permalink(); ?>">
                                    <?php the_post_thumbnail( 'post-thumbnail', array( 'class' => 'img-responsive' ) ); ?>
                                </a>
                            </div>
                        </div>
                        <div class="col-md-8">
                            <?php get_template_part( 'content', get_post_format() ); ?>
                        </div>
                    </div>
                </article>

                <?php else : ?>

                <article id="post-<?php the_ID(); ?>" <?php post_class(); ?>>
                    <?php get_template_part( 'content', get_post_format() ); ?>
                </article>

                <?php endif; ?>

        <?php

                /* End the loop */
                endwhile;

                the_posts_pagination( array( 
                    'prev_text' => '<span class="fa fa-chevron-left"></span>', 
                    'next_text' => '<span class="fa fa-chevron-right"></span>', 
                ) );

            /* If no content, include the "No posts found" template. */
            else :
                get_template_part( 'content', 'none' );

            endif;
        ?>

    </div>
</div>

<?php get_sidebar(); ?>

<?php get_footer(); ?>