<?php

/**
 * Mino filters
 *
 * @package 	Mino
 * @since 		1.0.0
 * @version		1.0.5
 */

if ( ! function_exists( 'mino_change_stylesheet_uri' ) ) {
	function mino_change_stylesheet_uri( $stylesheet_uri, $stylesheet_dir_uri ) {
		if ( SCRIPT_DEBUG !== false ) {
			return trailingslashit( $stylesheet_dir_uri ) . 'assets/css/theme.css';
		} else {
			return trailingslashit( $stylesheet_dir_uri ) . 'assets/css/mino.min.css';
		}
	}
}
add_filter( 'stylesheet_uri', 'mino_change_stylesheet_uri', 10, 2 );

/**
 * Change class for menu dropdown
 *  @param  string 	$class_name 	Default class name for dropdown toogle class
 *  @return -
 */
if ( ! function_exists( 'mino_change_dropdown_toggle_class' ) ) {
	function mino_change_dropdown_toggle_class( $class_name ) {
		return 'dropdown';
	}
}
add_filter( 'mino_menu_dropdown_class', 'mino_change_dropdown_toggle_class' );

/**
 * Change class for sub menu
 *  @param  string 	$class_name  	Default class name for sub menu class
 *  @return -
 */
if ( ! function_exists( 'mino_change_sub_menu_class' ) ) {
	function mino_change_sub_menu_class( $class_name ) {
		return 'sub-menu';
	}
}
add_filter( 'mino_sub_menu_class', 'mino_change_sub_menu_class' );

/**
 * Show comment form
 *  @return -
 */
if ( ! function_exists( 'mino_comment_form' ) ) {
	function mino_comment_form( $args ) {

		$post_id = get_the_ID();

		$commenter 		= wp_get_current_commenter();
		$user 			= wp_get_current_user();
		$user_identity 	= $user->exists() ? $user->display_name : '';

		$commenter 	= wp_get_current_commenter();
		$req 		= get_option( 'require_name_email' );
		$aria_req 	= ( $req ? " aria-required='true'" : '' );

		$comments_fields = array(
			'author' 	=> '<div class="form-group col-md-4 comment-form-author"><label for="author">' . __( 'Name', 'mino' ) . '</label> ' . ( $req ? '<sup class="required">*</sup>' : '' ) . '<input id="author" name="author" class="form-field" type="text" value="' . esc_attr( $commenter['comment_author'] ) . '" ' . $aria_req . ' /></div>',
			'email' 	=> '<div class="form-group col-md-4 comment-form-email"><label for="email">' . __( 'Email', 'mino' ) . '</label> ' . ( $req ? '<sup class="required">*</sup>' : '' ) . '<input id="email" name="email" class="form-field" type="text" value="' . esc_attr(  $commenter['comment_author_email'] ) . '" ' . $aria_req . ' /></div>',
			'url' 		=> '<div class="form-group col-md-4 comment-form-url"><label for="url">' . __( 'Website', 'mino' ) . '</label>' . '<input id="url" name="url" class="form-field" type="text" value="' . esc_attr( $commenter['comment_author_url'] ) . '" /></div>',
		);

		$required_text = sprintf( ' ' . __( 'Required fields are marked %s', 'mino' ), '<span class="required">*</span>' );

		$comments_args = array(
			'id_form'           	=> 'commentform',
			'class_form'      		=> 'row',
			'id_submit'         	=> 'submit',
			'class_submit'      	=> 'submit btn btn-md',
			'name_submit'       	=> 'submit',
			'title_reply'       	=> __( 'Leave a <span>Comment</span>', 'mino' ),
			'title_reply_to'    	=> __( 'Leave a <span>Reply</span> to %s', 'mino' ),
			'title_reply_before'   	=> '<h3 id="reply-title" class="comment-reply-title">',
			'title_reply_after'    	=> '</h3>',
			'cancel_reply_before'  	=> ' <small>',
			'cancel_reply_after'   	=> '</small>',
			'cancel_reply_link' 	=> __( 'Cancel', 'mino' ),
			'label_submit'      	=> __( 'Submit', 'mino' ),
			'submit_button'        	=> '<input name="%1$s" type="submit" id="%2$s" class="%3$s" value="%4$s" />',
			'submit_field'         	=> '<div class="col-md-12 respond">%1$s %2$s</div>',
			'format'            	=> 'html',
			'comment_field' 		=>  '<div class="col-md-12"><div class="form-group comment-form-comment"><label for="comment">' . __( 'Comment', 'mino' ) . '</label><textarea id="comment" name="comment" class="form-field" rows="6" aria-required="true">' .	'</textarea></div></div>',
			'must_log_in' 			=> '<div class="col-md-12 must-log-in">' . sprintf( __( 'You must be <a href="%s">logged in</a> to post a comment.', 'mino' ), wp_login_url( apply_filters( 'the_permalink', esc_url( get_permalink( $post_id ) ) ) ) ) . '</div>',
			'logged_in_as' 			=> '<div class="col-md-12 logged-in-as">' . sprintf( __( 'Logged in as <a href="%1$s" aria-label="Logged in as %2$s. Edit your profile.">%2$s</a>. <a href="%3$s">Log out?</a>', 'mino' ), get_edit_user_link(), $user_identity, wp_logout_url( apply_filters( 'the_permalink', esc_url( get_permalink( $post_id ) ) ) ) ) . '</div>',
			'comment_notes_before' 	=> '<div class="col-md-12 comment-notes"><span id="email-notes">' . __( 'Your email address will not be published.', 'mino' ) . '</span>'. ( $req ? $required_text : '' ) . '</div>',
			'comment_notes_after' 	=> '',
			'fields' 				=> apply_filters( 'comment_form_default_fields', $comments_fields ),
		);

		return $comments_args;

	}
}
add_filter( 'comment_form_defaults', 'mino_comment_form' );

/**
 * Add filter for background pattern template
 *  @return 	array 	Background pattern list
 */
if ( ! function_exists( 'mino_set_bg_pattern_template' ) ) {
	function mino_set_bg_pattern_template( $args ) {

		$pattern = array(
			'pattern_1' => MINO_THEME_URI_ASSETS . 'img/pattern-01.png',
			'pattern_2' => MINO_THEME_URI_ASSETS . 'img/pattern-02.png',
			'pattern_3' => MINO_THEME_URI_ASSETS . 'img/pattern-03.png',
			'pattern_4' => MINO_THEME_URI_ASSETS . 'img/pattern-04.png',
			'pattern_5' => MINO_THEME_URI_ASSETS . 'img/pattern-05.png',
			'pattern_6' => MINO_THEME_URI_ASSETS . 'img/pattern-06.png',
		);

		return apply_filters( 'mino_bg_pattern_template_choices', $pattern );

	}
}
add_filter( 'mino_bg_pattern_template', 'mino_set_bg_pattern_template' );

/**
 * Add filter for layout template
 *  @return 	array 	Layout templates list
 */
if ( ! function_exists( 'mino_template_layout_set' ) ) {
	function mino_template_layout_set( $args ) {

		$pattern = array(
			'full' 	=> MINO_THEME_URI_ASSETS . 'img/layout-full.gif',
			'left' 	=> MINO_THEME_URI_ASSETS . 'img/layout-left.gif',
			'right' => MINO_THEME_URI_ASSETS . 'img/layout-right.gif'
		);

		return apply_filters( 'mino_layout_template_choices', $pattern );

	}
}
add_filter( 'mino_template_layout', 'mino_template_layout_set' );

/**
 * Add filter for color template
 *  @return 	array 	Theme color list
 */
if ( ! function_exists( 'mino_set_bg_color_template' ) ) {
	function mino_set_bg_color_template( $args ) {

		$pattern = array(
			'color_1' => array( 'color' => '#181616', 'label' => 'black' ),
			'color_2' => array( 'color' => '#FF7C44', 'label' => 'orange' ),
			'color_3' => array( 'color' => '#E74C3C', 'label' => 'red' ),
			'color_4' => array( 'color' => '#81B441', 'label' => 'green' ),
			'color_5' => array( 'color' => '#23a0bf', 'label' => 'blue' )
		);

		return apply_filters( 'mino_color_template_choices', $pattern );

	}
}
add_filter( 'mino_bg_color_template', 'mino_set_bg_color_template' );

/**
 * Mino read more excerpt
 *  @param  string $more Default value
 *  @return html Read more structure
 */
if ( ! function_exists( 'mino_excerpt_more' ) ) {
	function mino_excerpt_more( $more ) {
		return '<div class="readmore"><a href="' . esc_url( get_permalink( get_the_ID() ) ) . '" class="btn readmore-link btn-inverse">' . __( 'Read More', 'mino' ) . '</a></div>';
	}
}
add_filter( 'excerpt_more', 'mino_excerpt_more' );

/**
 * Set custom HTML for custom logo
 * @return string New HMTL output for custom logo
 */
function mino_logo_custom_html( $output ) {

	/* Add href class */
	if ( strpos( $output, 'class="custom-logo-link"' ) ) {
		$output = str_replace( 'class="custom-logo-link"', 'class="custom-logo-link brand"', $output );
	}

	return $output;

}
add_filter( 'get_custom_logo', 'mino_logo_custom_html' );

/**
 * Woocommerce filter part
 */
if ( in_array( 'woocommerce/woocommerce.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ) ) ) {

	/**
	 *  Header menu add ajax for item button
	 *  @param 	array $fragments Woocommerce cart box
	 *  @return array $fragments Woocommerce cart box
	 */
	if ( ! function_exists( 'mino_header_add_to_cart_fragment' ) ) {
		function mino_header_add_to_cart_fragment( $fragments ) {
			ob_start();
		?>
			<div class="mino-mini-cart">
				<a class="ecommerce-ext-menu max-cart-menu cart-contents" title="<?php _e( 'View your shopping cart', 'mino' ); ?>">
					<div class="ecommerce-ext-menu-img-container img-full">
						<i class="fa fa-shopping-cart color-theme fa-24px"></i>
					</div>
					<label class="ecommerce-ext-menu-label cart-info">
						<?php
							echo sprintf (_n(
								'item',
								'items', 'mino' ),
								WC()->cart->get_cart_contents_count(),
								WC()->cart->get_cart_contents_count() );
						?> - <?php echo WC()->cart->get_cart_total(); ?>
						<span class="ecommerce-ext-menu-counter">
							<?php
								echo sprintf (_n(
									'%d',
									'%d', 'mino' ),
									WC()->cart->get_cart_contents_count(),
									WC()->cart->get_cart_contents_count()
								);
							?>
						</span>
					</label>
					<div class="mini-cart">
						<?php woocommerce_mini_cart(); ?>
					</div>
				</a>
			</div>
		<?php

			$fragments['.mino-mini-cart'] = ob_get_clean();

			return $fragments;
		}
	}
	add_filter( 'woocommerce_add_to_cart_fragments', 'mino_header_add_to_cart_fragment' );

	if ( ! function_exists( 'mino_woocommerce_get_price_html_from_to' ) ) {
		function mino_woocommerce_get_price_html_from_to( $price, $from, $to, $this ) {
			$price = '<div class="price-reg"><del>' . ( ( is_numeric( $from ) ) ? wc_price( $from ) : $from ) . '</del></div> <div class="price-sale"><span>' . ( ( is_numeric( $to ) ) ? wc_price( $to ) : $to ) . '</div></span>';

			return apply_filters( 'mino_set_price_output', $price );
		}
	}
	add_filter( 'woocommerce_get_price_html_from_to', 'mino_woocommerce_get_price_html_from_to', 10, 4 );

	if ( ! function_exists( 'mino_update_extra_profile_fields' ) ) {
		function mino_update_extra_profile_fields( $user_id ) {
		 	if ( current_user_can( 'edit_user', $user_id ) ) {
		 		if ( isset( $_POST['account_phone'] ) ) {
			     	update_user_meta( $user_id, 'mino_user_phone_number', sanitize_text_field( $_POST['account_phone'] ) );
		 		}
		 	}
		}
	}
	add_action( 'edit_user_profile_update', 'mino_update_extra_profile_fields' );

	if ( ! function_exists( 'mino_woocommerce_product_description_heading_hide' ) ) {
		function mino_woocommerce_product_description_heading_hide() {
			return '';
		}
	}
	add_filter( 'woocommerce_product_description_heading', 'mino_woocommerce_product_description_heading_hide' );

	if ( ! function_exists( 'mino_woocommerce_product_additional_information_heading_hide' ) ) {
		function mino_woocommerce_product_additional_information_heading_hide() {
			return '';
		}
	}
	add_filter( 'woocommerce_product_additional_information_heading', 'mino_woocommerce_product_additional_information_heading_hide' );

	if ( ! function_exists( 'mino_remove_postcount_bracket' ) ) {
		function mino_remove_postcount_bracket ( $variable ) {
		   $variable = str_replace( '</a>', '', $variable );
		   $variable = str_replace( '<span class="count">(', '<span class="count">', $variable );
		   $variable = str_replace( ')', '', $variable );
		   $variable = str_replace( '</span>', '</span></a>', $variable );
		   return apply_filters( 'mino_set_bracket', $variable );
		}
	}

	add_filter( 'woocommerce_add_to_cart_message', 'mino_custom_add_to_cart_message' );

	if ( ! function_exists( 'mino_custom_add_to_cart_message' ) ) {
		function mino_custom_add_to_cart_message() {

		    global $woocommerce;

		    // Output success messages
		    if ( get_option( 'woocommerce_cart_redirect_after_add' ) == 'yes' ) :

		        $return_to = esc_url( get_permalink(woocommerce_get_page_id('shop')) );

		        $message   = sprintf('<a href="%s" class="button">%s</a> %s', $return_to, __('Continue Shopping &rarr;', 'mino' ), __('Product successfully added to your cart.', 'mino' ) );

		    else :

		        $message = sprintf('<a href="%s" class="button">%s</a> %s', esc_url( get_permalink(woocommerce_get_page_id('cart'))), __('View Cart &rarr;', 'mino' ), __('Product successfully added to your cart.', 'mino' ) );

		    endif;

		  	return $message;
		}
	}

	if ( ! function_exists( 'mino_woocommerce_product_filter_form' )  ) {
		function mino_woocommerce_product_filter_form( $form ) {

			$form = '<form role="search" method="get" class="woocommerce-product-search" action="' . esc_url( home_url() ) . '">
				<div class="form-group" id="form-search">
					<label for="search"><span class="fa fa-search"></span></label>
					<input id="woocommerce-product-search-field" name="s" type="search" class="form-field" placeholder="' . __( 'Search product', 'mino' ) . '">
					<input type="hidden" name="post_type" value="product">
				</div>
			</form>';

			return $form;

		}
	}
	add_filter( 'get_product_search_form', 'mino_woocommerce_product_filter_form' );

	if ( ! function_exists( 'mino_woocommerce_rename_tabs' ) ) {
		function mino_woocommerce_rename_tabs( $tabs ) {

			global $product, $post;

			$tabs['reviews']['title'] 		= '<span class="fa fa-comment-o visible-xs"></span> <span class="hidden-xs">' . __( 'Ratings', 'mino' ) . '</span>';

			if ( $post->post_content ) {
				$tabs['description']['title'] 	= '<span class="fa fa-file-text-o visible-xs"></span> <span class="hidden-xs">' . __( 'Information', 'mino' ) . '</span>';
			}
			if ( ! empty( $product->product_attributes ) && ! empty( $tabs['additional_information'] ) ) {
				$tabs['additional_information']['title'] 	= '<span class="fa fa-info visible-xs"></span> <span class="hidden-xs">' . __( 'Product Details', 'mino' ) . '</span>';
			}

			return $tabs;

		}
	}
	add_filter( 'woocommerce_product_tabs', 'mino_woocommerce_rename_tabs', 98 );

	if ( ! function_exists( 'mino_custom_woocommerce_breadcrumb' ) ) {
		function mino_custom_woocommerce_breadcrumb( $args ){

			$args['wrap_before'] = '<div class="col-md-12"><nav class="woocommerce-breadcrumb" ' . ( is_single() ? 'itemprop="breadcrumb"' : '' ) . '>';
			$args['wrap_after'] = '</nav></div>';

			return $args;

		}
	}
	add_filter( 'woocommerce_breadcrumb_defaults', 'mino_custom_woocommerce_breadcrumb', 10, 1 );

}