<?php

/**
 * Mino setup
 *
 * @package Mino
 * @since Mino 1.0.2
 */

if ( ! function_exists( 'mino_setup' ) ) :

/**
 * Set default settings for mino_satu
 * @return -
 */
function mino_setup() {

	/* Set translation */
	load_theme_textdomain( 'mino', get_template_directory() . '/languages' );

	/* Add default posts and comments RSS feed links to head */
	add_theme_support( 'automatic-feed-links' );

	/* Set title will be set by WordPress */
	add_theme_support( 'title-tag' );

	/* Enable support for Post Thumbnails on posts and pages */
	add_theme_support( 'post-thumbnails' );
	set_post_thumbnail_size( 825, 510, true );

	/* Set navigation menus on themes */
	register_nav_menus( array(
		'primary' 				=> __( 'Primary Menu',      'mino' ),
		'secondary' 			=> __( 'Secondary Menu',	'mino' )
	) );

	/* Set sidebar */
	register_sidebar( array(
		'name' 			=> __( 'Sidebar Widget', 'mino' ),
		'id' 			=> 'sidebar-widget',
		'description' 	=> __( 'Displayed on sidebar area', 'mino' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget' 	=> '</aside>',
		'before_title' 	=> '<h5 class="widget-title">',
		'after_title' 	=> '</h5>',
	) );

	register_sidebar( array(
		'name' 			=> __( 'Woocommerce Sidebar Widget', 'mino' ),
		'id' 			=> 'sidebar-widget-ecommerce',
		'description' 	=> __( 'Displayed on woocommerce sidebar area', 'mino' ),
		'before_widget' => '<aside id="%1$s" class="widget clearfix %2$s">',
		'after_widget' 	=> '</aside>',
		'before_title' 	=> '<h5 class="widget-title">',
		'after_title' 	=> '</h5>',
	) );

	register_sidebar( array(
		'name' 			=> __( 'Footer Widget', 'mino' ),
		'id' 			=> 'footer-widget',
		'description' 	=> __( 'Displayed on footer area', 'mino' ),
		'before_widget' => '<div class="col-md-3"><aside id="%1$s" class="widget %2$s">',
		'after_widget' 	=> '</aside></div>',
		'before_title' 	=> '<h5 class="widget-title">',
		'after_title' 	=> '</h5>',
	) );

	register_sidebar( array(
		'name' 			=> __( 'Header Widget', 'mino' ),
		'id' 			=> 'header-widget',
		'description' 	=> __( 'Displayed on header area', 'mino' ),
		'before_widget' => '<div class="col-md-3 pull-right"><aside id="%1$s" class="widget %2$s">',
		'after_widget' 	=> '</aside></div>',
		'before_title' 	=> '<h5 class="widget-title">',
		'after_title' 	=> '</h5>',
	) );

	register_sidebar( array(
		'name' 			=> __( 'Woocommerce Header Widget', 'mino' ),
		'id' 			=> 'header-commerce-widget',
		'description' 	=> __( 'Displayed on woocommerce header area', 'mino' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget' 	=> '</aside>',
		'before_title' 	=> '<h5 class="widget-title">',
		'after_title' 	=> '</h5>',
	) );

	/* Core markup for this part as valid HTML4 */
	add_theme_support( 'html5', array(
		'search-form', 'comment-form', 'comment-list', 'gallery', 'caption'
	) );

	/* Support for Post Formats */
	add_theme_support( 'post-formats', array(
		'aside', 'image', 'video', 'quote', 'link', 'gallery', 'status', 'audio', 'chat'
	) );

	/* Support for post template */
	add_theme_support( 'post-thumbnails' );

	/* Support custom logo */
	$args = array(
		'height'        => 90,
		'width'         => 370,
		'flex-height'   => true,
		'flex-width'    => true,
		'upload'		=> true,
		'header-text' 	=> array( 'site-title', 'site-description' )
	);
	add_theme_support( 'custom-logo', $args );

	/* Support custom background */
	$defaults = array(
		'default-color'          => '',
		'default-image'          => '',
		'default-repeat'         => '',
		'default-position-x'     => '',
		'default-attachment'     => '',
		'wp-head-callback'       => '_custom_background_cb'
	);
	add_theme_support( 'custom-background', $defaults );

	/* Support Woocommerce */
	add_theme_support( 'woocommerce' );

	/* Add image size */
	add_image_size( 'mino-square-size', 376, 376, array( 'center', 'center' ) );
	add_image_size( 'mino-potrait-size', 240, 320, true );
	add_image_size( 'mino-full-size', 1200, 300, true );

}

endif;
add_action( 'after_setup_theme', 'mino_setup' );

/* Set standard content width */
if ( ! isset( $content_width ) ) {
	$content_width = 660;
}