<?php
/**
 * Cart Page
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/cart/cart.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you (the theme developer).
 * will need to copy the new files to your theme to maintain compatibility. We try to do this.
 * as little as possible, but it does happen. When this occurs the version of the template file will.
 * be bumped and the readme will list any important changes.
 *
 * @see     http://docs.woothemes.com/document/template-structure/
 * @version 2.3.8
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

wc_print_notices();

do_action( 'woocommerce_before_cart' ); ?>

<!-- Cart Form -->
<form action="<?php echo esc_url( wc_get_cart_url() ); ?>" method="post">

<?php do_action( 'woocommerce_before_cart_table' ); ?>

<table class="shop_table shop_table_responsive cart" cellspacing="0">
	<thead>
		<tr>
			<th class="product-remove">&nbsp;</th>
			<th class="product-thumbnail">&nbsp;</th>
			<th class="product-name"><?php _e( 'Product', 'mino' ); ?></th>
			<th class="product-price td-center"><?php _e( 'Price', 'mino' ); ?></th>
			<th class="product-quantity td-center"><?php _e( 'Quantity', 'mino' ); ?></th>
			<th class="product-subtotal td-center"><?php _e( 'Total', 'mino' ); ?></th>
		</tr>
	</thead>
	<tbody>
		<?php do_action( 'woocommerce_before_cart_contents' ); ?>

		<?php
		foreach ( WC()->cart->get_cart() as $cart_item_key => $cart_item ) {
			$_product     = apply_filters( 'woocommerce_cart_item_product', $cart_item['data'], $cart_item, $cart_item_key );
			$product_id   = apply_filters( 'woocommerce_cart_item_product_id', $cart_item['product_id'], $cart_item, $cart_item_key );

			if ( $_product && $_product->exists() && $cart_item['quantity'] > 0 && apply_filters( 'woocommerce_cart_item_visible', true, $cart_item, $cart_item_key ) ) {
				?>
				<tr class="<?php echo esc_attr( apply_filters( 'woocommerce_cart_item_class', 'cart_item', $cart_item, $cart_item_key ) ); ?>">

					<td class="product-remove">
						<?php
							echo apply_filters( 'woocommerce_cart_item_remove_link', sprintf(
								'<a href="%s" class="remove" title="%s" data-product_id="%s" data-product_sku="%s">&times; <span class="hidden-lg hidden-md remove-product-link">Remove from cart</span></a>',
								esc_url( WC()->cart->get_remove_url( $cart_item_key ) ),
								__( 'Remove this item', 'mino' ),
								esc_attr( $product_id ),
								esc_attr( $_product->get_sku() )
							), $cart_item_key );
						?>
					</td>

					<td class="product-thumbnail">
						<?php
							$thumbnail = apply_filters( 'woocommerce_cart_item_thumbnail', $_product->get_image(), $cart_item, $cart_item_key );

							if ( ! $_product->is_visible() ) {
								echo $thumbnail;
							} else {
								printf( '<a href="%s">%s</a>', esc_url( $_product->get_permalink( $cart_item ) ), $thumbnail );
							}
						?>
					</td>

					<td class="product-name" data-title="<?php _e( 'Product', 'mino' ); ?>">
						<?php
							if ( ! $_product->is_visible() ) {
								echo apply_filters( 'woocommerce_cart_item_name', $_product->get_title(), $cart_item, $cart_item_key ) . '&nbsp;';
							} else {
								echo apply_filters( 'woocommerce_cart_item_name', sprintf( '<a href="%s">%s</a>', esc_url( $_product->get_permalink( $cart_item ) ), $_product->get_title() ), $cart_item, $cart_item_key );
							}

							// Meta data
							echo WC()->cart->get_item_data( $cart_item );
							
							// Backorder notification
							if ( $_product->backorders_require_notification() && $_product->is_on_backorder( $cart_item['quantity'] ) ) {
								echo '<p class="backorder_notification">' . esc_html__( 'Available on backorder', 'mino' ) . '</p>';
							}
						?>
					</td>

					<td class="product-price td-right" data-title="<?php _e( 'Price', 'mino' ); ?>">
						<?php
							echo apply_filters( 'woocommerce_cart_item_price', WC()->cart->get_product_price( $_product ), $cart_item, $cart_item_key );
						?>
					</td>

					<td class="product-quantity td-center" data-title="<?php _e( 'Quantity', 'mino' ); ?>">
						<?php
							if ( $_product->is_sold_individually() ) {
								$product_quantity = sprintf( '1 <input type="hidden" name="cart[%s][qty]" value="1" />', $cart_item_key );
							} else {
								$product_quantity = woocommerce_quantity_input( array(
									'input_name'  => "cart[{$cart_item_key}][qty]",
									'input_value' => $cart_item['quantity'],
									'max_value'   => $_product->backorders_allowed() ? '' : $_product->get_stock_quantity(),
									'min_value'   => '0'
								), $_product, false );
							}

							echo apply_filters( 'woocommerce_cart_item_quantity', $product_quantity, $cart_item_key, $cart_item );
						?>
					</td>

					<td class="product-subtotal td-right" data-title="<?php _e( 'Total', 'mino' ); ?>">
						<?php
							echo apply_filters( 'woocommerce_cart_item_subtotal', WC()->cart->get_product_subtotal( $_product, $cart_item['quantity'] ), $cart_item, $cart_item_key );
						?>
					</td>
				</tr>
				<?php
			}
		}

		do_action( 'woocommerce_cart_contents' );
		do_action( 'woocommerce_cart_actions' );
		do_action( 'woocommerce_after_cart_contents' ); 

		?>
	</tbody>
</table>

<div class="row">
	<div class="col-md-3 col-xs-4">
		<a href="<?php echo esc_url( get_permalink( woocommerce_get_page_id( 'shop' ) ) ); ?>" class="btn btn-success cart-continue-button"><span class="hidden-xs"><?php _e( 'Continue shopping', 'mino' ); ?></span><i class="fa fa-shopping-cart cart-continue"></i></a>
	</div>
	<div class="col-md-offset-5 col-md-2 col-xs-4">
		<button type="submit" class="btn btn-primary cart-empty-button" name="clear_cart">
			<span class="hidden-xs"><?php esc_attr_e( 'Empty Cart', 'mino' ); ?></span> <i class="fa fa-trash cart-empty"></i>
		</button>
	</div>
	<div class="col-md-2 col-xs-4">
		<input type="hidden" name="update_cart" value="update cart" />
		<button type="submit" class="btn btn-primary cart-update-button">
			<span class="hidden-xs"><?php esc_attr_e( 'Update Cart', 'mino' ); ?></span> <i class="fa fa-pencil cart-update"></i>
		</button>
	</div>
</div>

<?php wp_nonce_field( 'woocommerce-cart' ); ?>

<?php do_action( 'woocommerce_after_cart_table' ); ?>

</form>
<!-- / Cart Form -->

<div class="row">
	<div class="col-md-4 col-md-offset-4 col-xs-12 cart-section-part">
		<?php if ( wc_coupons_enabled() ) { ?>
			<div class="coupon">
				<h5 class="page-subtitle">Discount Coupon</h5>
				<label class="cart-form-label" for="coupon_code">
					<?php _e( 'Enter your coupon code if you have one:', 'mino' ); ?>
				</label>
				<form action="<?php echo esc_url( wc_get_cart_url() ); ?>" method="post">
					<div class="form-group">
						<input type="text" name="coupon_code" class="input-text" id="coupon_code" value="" placeholder="<?php esc_attr_e( 'Coupon code', 'mino' ); ?>" />
					</div>
					<div class="form-group">
						<input type="submit" class="btn btn-success btn-auto" name="apply_coupon" value="<?php esc_attr_e( 'Apply Coupon', 'mino' ); ?>" />
					</div>
					<?php do_action( 'woocommerce_cart_coupon' ); ?>
				</form>
			</div>
			<?php wp_nonce_field( 'woocommerce-cart' ); ?>
		<?php } ?>
	</div>

	<div class="col-md-4 col-xs-12 cart-section-part">
		<div class="cart-collaterals">
			<?php do_action( 'woocommerce_cart_collaterals' ); ?>
		</div>
	</div>
</div>


<?php do_action( 'woocommerce_after_cart' ); ?>
