<?php
/**
 * My Addresses
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/myaccount/my-address.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see     https://docs.woothemes.com/document/template-structure/
 * @version 2.6.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

$customer_id = get_current_user_id();

if ( ! wc_ship_to_billing_address_only() && get_option( 'woocommerce_calc_shipping' ) !== 'no' ) {
	$page_title = apply_filters( 'woocommerce_my_account_my_address_title', __( 'My Addresses', 'mino' ) );
	$get_addresses    = apply_filters( 'woocommerce_my_account_get_addresses', array(
		'billing' => __( 'Billing Address', 'mino' ),
		'shipping' => __( 'Shipping Address', 'mino' )
	), $customer_id );
} else {
	$page_title = apply_filters( 'woocommerce_my_account_my_address_title', __( 'My Address', 'mino' ) );
	$get_addresses    = apply_filters( 'woocommerce_my_account_get_addresses', array(
		'billing' =>  __( 'Billing Address', 'mino' )
	), $customer_id );
}

$oldcol = 1;
$col = 1;
?>

<div class="account-section">

	<h2 class="page-subtitle"><?php echo $page_title; ?></h2>

	<p class="myaccount_address">
		<?php echo apply_filters( 'woocommerce_my_account_my_address_description', __( 'The following addresses will be used on the checkout page by default.', 'mino' ) ); ?>
	</p>

	<?php if ( ! wc_ship_to_billing_address_only() && get_option( 'woocommerce_calc_shipping' ) !== 'no' ) echo '<div class="col2-set addresses">'; ?>

	<?php foreach ( $get_addresses as $name => $title ) : ?>

		<div class="col-<?php echo ( ( $col = $col * -1 ) < 0 ) ? 1 : 2; ?> address">
			<header class="account-subtitle">
				<h3 class="page-subtitle">
					<?php echo $title; ?> <a href="<?php echo wc_get_endpoint_url( 'edit-address', $name ); ?>" class="edit btn btn-success btn-side-title"><?php _e( 'Edit', 'mino' ); ?></a>
				</h3>
			</header>
			<address>
				<?php
					$address = apply_filters( 'woocommerce_my_account_my_address_formatted_address', array(
						'first_name'  => 'name|:|' . get_user_meta( $customer_id, $name . '_first_name', true ),
						'last_name'   => get_user_meta( $customer_id, $name . '_last_name', true ),
						'company'     => 'company|:|' . get_user_meta( $customer_id, $name . '_company', true ),
						'address_1'   => 'address|:|' . get_user_meta( $customer_id, $name . '_address_1', true ),
						'address_2'   => get_user_meta( $customer_id, $name . '_address_2', true ),
						'city'        => 'city|:|' . get_user_meta( $customer_id, $name . '_city', true ),
						'state'       => 'state|:|' . get_user_meta( $customer_id, $name . '_state', true ),
						'postcode'    => 'postcode|:|' . get_user_meta( $customer_id, $name . '_postcode', true ),
						'country'     => 'country|:|' . get_user_meta( $customer_id, $name . '_country', true )
					), $customer_id, $name );

					$formatted_address = WC()->countries->get_formatted_address( $address );

					if ( ! $formatted_address ) :
						_e( 'You have not set up this type of address yet.', 'mino' );
					else :
						$formatted_address_raw 	= explode( '<br/>', $formatted_address );
				?>
						<div class="info-address">
						<?php 
							foreach ( $formatted_address_raw as $key => $value ) :
								$items 	= explode( '|:|', $value );
								$label 	= $text = null;
								if ( count( $items ) > 1 ) :
									$label 	= $items[0];					
									$text 	= $items[1];				
						?>

							<div class="info-item-container">
								<div class="info-item">
									<span><?php echo ucfirst( $label ); ?> : </span>
									<span><?php echo $text; ?></span>
								</div>
							</div>

						<?php 
								endif;
							endforeach; 
						?>
						</div>
				<?php endif; ?>
			</address>
		</div>

	<?php endforeach; ?>

	<?php if ( ! wc_ship_to_billing_address_only() && wc_shipping_enabled() ) echo '</div>'; ?>

</div>